require 'spec_helper'

RSpec.describe 'Address' do
  it 'works' do
    address = build(:address)

    expect(address.name).to eq 'Bobby Axelrod'
    expect(address.line_1).to eq 'Axe Capital'
  end

  describe 'with required parameters' do
    it 'is valid' do
      address = build(:required_address)
      expect(address).to be_valid
    end

    it 'is invalid with missing parameters' do
      address = build(:required_address, name: nil)
      expect(address).not_to be_valid
      expect(address.errors.messages).to eq(name: ["can't be blank"])
    end
  end

  describe 'with complete parameters' do
    it 'is valid' do
      address = build(:complete_address)
      expect(address.valid?).to be true
    end

    it 'is invalid without the required parameters' do
      address = build(:complete_address, name: nil)
      expect(address.valid?).to be false
      expect(address.errors.messages).to eq(name: ["can't be blank"])
    end

    it 'is valid without the optional parameters' do
      address = build(:complete_address, company: nil)
      expect(address.valid?).to be true
    end
  end
end