require 'spec_helper'

RSpec.describe "@order.cancel" do
  before do
    Xpost.configure do |config|
      config.api_key        = ENV['XPOST_STAGING_API_KEY']
      config.secret_key     = ENV['XPOST_STAGING_SECRET_KEY']
      config.staging_url    = "https://api.staging.lbcx.ph/v1"
      config.production_url = "https://api.staging.lbcx.ph/v1"
    end

    @auth_token = Xpost::Authentication.authenticate(Xpost.configuration.api_key, Xpost.configuration.secret_key)
    @order = build(:order)
    @order_data = Xpost::Orders.create(@auth_token, @order, "small-pouch")
    @tracking_number = @order_data[:tracking_number]
    @order = Xpost::Orders.find(@auth_token, @tracking_number)
  end

  it 'makes sure the order exists' do
    expect(Xpost::Orders.exists?(@auth_token, @tracking_number)).to eq true
  end

  it 'cancels a pending order' do
    res = Xpost::Orders.cancel(@auth_token, @tracking_number)

    expect(res[:tracking_number]).to eq @tracking_number
    expect(res[:old_status]).to eq "pending"
    expect(res[:new_status]).to eq "canceled"
  end

  it 'doesnt accept non-pending orders' do
    res = Xpost::Orders.confirm(@auth_token, @tracking_number)
    expect(res[:new_status]).to eq "confirmed"

    expect { Xpost::Orders.cancel(@auth_token, @tracking_number) }.to raise_error "Order isn't pending"
  end
end