require 'spec_helper'

RSpec.describe "@order.for_pickup" do
  before do
    Xpost.configure do |config|
      config.api_key        = ENV['XPOST_STAGING_API_KEY']
      config.secret_key     = ENV['XPOST_STAGING_SECRET_KEY']
      config.staging_url    = "https://api.staging.lbcx.ph/v1"
      config.production_url = "https://api.staging.lbcx.ph/v1"
    end

    @auth_token = Xpost::Authentication.authenticate(Xpost.configuration.api_key, Xpost.configuration.secret_key)
    @order = build(:order)
    @order_data = Xpost::Orders.create(@auth_token, @order, "small-pouch")
    @tracking_number = @order_data[:tracking_number]
    @order = Xpost::Orders.find(@auth_token, @tracking_number)
  end

  it 'already has a delivery address' do
    expect(@order[:delivery_address]).to be_present
    expect(@order[:delivery_address][:name]).to eq "Bobby Axelrod"
  end

  it 'requires a pickup address' do
    Xpost::Orders.confirm(@auth_token, @tracking_number)
    pickup_address = nil

    expect{ Xpost::Orders.for_pickup(@auth_token, @tracking_number, pickup_address) }.to raise_error "Missing pickup address"
  end

  it 'only allows confirmed orders' do
    expect{ Xpost::Orders.for_pickup(@auth_token, @tracking_number, nil) }.to raise_error "Order isn't confirmed"

    order = Xpost::Orders.confirm(@auth_token, @tracking_number)
    expect(order[:new_status]).to eq "confirmed"

    pickup_address = build(:complete_address_pickup)
    order = Xpost::Orders.for_pickup(@auth_token, @tracking_number, pickup_address)

    expect(order[:new_status]).to eq "for_pickup"
  end
end