require 'spec_helper'

RSpec.describe "@order.get_shipping_labels" do
  before do
    Xpost.configure do |config|
      config.api_key        = ENV['XPOST_STAGING_API_KEY']
      config.secret_key     = ENV['XPOST_STAGING_SECRET_KEY']
      config.staging_url    = "https://api.staging.lbcx.ph/v1"
      config.production_url = "https://api.staging.lbcx.ph/v1"
    end

    @auth_token = Xpost::Authentication.authenticate(Xpost.configuration.api_key, Xpost.configuration.secret_key)
    @order = build(:order)
    @order_data = Xpost::Orders.create(@auth_token, @order, "small-pouch")
    @tracking_number = @order_data[:tracking_number]
    @order = Xpost::Orders.find(@auth_token, @tracking_number)
  end

  describe 'for a single order' do
    it 'should expect the order to be for_pickup' do
      expect { Xpost::Orders.get_shipping_labels(@auth_token, @tracking_number) }.to raise_error "Order isn't for_pickup"

      Xpost::Orders.confirm(@auth_token, @tracking_number)
      expect { Xpost::Orders.get_shipping_labels(@auth_token, @tracking_number) }.to raise_error "Order isn't for_pickup"

      order = Xpost::Orders.for_pickup(@auth_token, @tracking_number, build(:complete_address_pickup))
      expect(order[:new_status]).to eq "for_pickup"

      expect { Xpost::Orders.get_shipping_labels(@auth_token, @tracking_number) }.not_to raise_error
    end

    it 'should return the shipping labels' do
      Xpost::Orders.confirm(@auth_token, @tracking_number)
      Xpost::Orders.for_pickup(@auth_token, @tracking_number, build(:complete_address_pickup))

      order = Xpost::Orders.get_shipping_labels(@auth_token, @tracking_number)

      expect(order[:awb]).to be_present
      expect(order[:pod]).to be_present
    end
  end
  
  describe 'for multiple orders' do
    it 'should return the shipping labels' do
      Xpost::Orders.confirm(@auth_token, @tracking_number)
      Xpost::Orders.for_pickup(@auth_token, @tracking_number, build(:complete_address_pickup))

      new_order = build(:order)
      new_order_data = Xpost::Orders.create(@auth_token, new_order, "small-pouch")

      tracking_numbers = [@tracking_number, new_order_data[:tracking_number]]

      order = Xpost::Orders.get_shipping_labels(@auth_token, @tracking_number)

      expect(order[:awb]).to be_present
      expect(order[:pod]).to be_present
    end
  end
  
end