require 'spec_helper'

RSpec.describe 'Item' do
  it 'works' do
    item = build(:product_item)

    expect(item).to be_valid
    expect(item.product_type).to eq "product"
    expect(item.description).to eq "orange shirt"
    expect(item.amount).to eq 1000
  end

  it 'requires a valid item_type' do
    expect(build(:product_item, product_type: "product")).to be_valid
    expect(build(:product_item, product_type: "productz")).not_to be_valid
  end

  describe 'with required parameters' do
    it 'is valid' do
      item = build(:product_item)
      expect(item).to be_valid
    end

    it 'is invalid with missing parameters' do
      item = build(:product_item, amount: nil)
      expect(item.valid?).to eq false
    end
  end

  describe 'with complete parameters' do
    it 'is valid' do
      item = build(:complete_product_item)
      expect(item).to be_valid
    end

    it 'is invalid without the required parameters' do
      item = build(:complete_product_item, product_type: nil)
      expect(item).not_to be_valid
    end

    it 'is valid without the optional parameters' do
      item = build(:complete_product_item, quantity: nil)
      expect(item).to be_valid
    end
  end
end

