require 'spec_helper'
require 'json'

RSpec.describe "Xpost::Order" do

  describe '.attributes' do
    before(:each) do
      @order = build(:order)
    end

    it 'returns the base order details' do
      attributes = @order.attributes

      expect(attributes[:buyer_name]).to eq "John Doe"
      expect(attributes[:email]).to eq "john@me.com"
      expect(attributes[:contact_number]).to eq "+6391712345678"
      expect(attributes[:currency]).to eq "PHP"
      expect(attributes[:total]).to eq 1000
      expect(attributes[:payment_method]).to eq "cod"
      expect(attributes[:payment_provider]).to eq "lbcx"
    end

    it 'returns the items' do
      attributes  = @order.attributes
      order_items = attributes[:items]

      expect(order_items).to be_present
      expect(order_items.first[:description]).to eq "red shirt"
      expect(order_items.first[:amount]).to eq 1000
    end

    it 'returns the delivery_address' do
      attributes        = @order.attributes
      delivery_address  = attributes[:delivery_address]

      expect(delivery_address).to be_present
      expect(delivery_address[:name]).to eq "Bobby Axelrod"
      expect(delivery_address[:line_1]).to eq "BGC Corporate Centre"
    end

    it 'returns the pickup_address' do
      @order            = build(:cod_order_ready_for_pickup)
      attributes        = @order.attributes
      pickup_address    = attributes[:pickup_address]

      expect(pickup_address).to be_present
      expect(pickup_address[:name]).to eq "Taylor Mason"
      expect(pickup_address[:line_1]).to eq "BGC Corporate Centre"
    end
  end

  # describe '.to_json' do
  #   it '.to_json matches API requirements' do
  #     skip 'array order is being a little b'
  #     @order = build(:order)
  #     order_json = {
  #       email: "john@me.com",
  #       buyer_name: "John Doe",
  #       contact_number: "+6391712345678",
  #       shipment: "small-pouch",
  #       total: 1000,
  #       currency: "PHP",
  #       payment_method: "cod",
  #       payment_provider: "lbcx",
  #       items: {
  #         type: "product",
  #         description: "red shirt",
  #         amount: 1000,
  #         quantity: 1,
  #         metadata: "Small"
  #       },
  #       delivery_address: {
  #         name: "Bobby Axelrod",
  #         shipment: "small-pouch",
  #         line_1: "855 Sixth Avenue",
  #         line_2: "5th floor",
  #         city: "New York",
  #         state: "NY",
  #         postal_code: 10001,
  #         country: "US",
  #         company: "Axe Capital",
  #         title: "CEO",
  #         email: "bobby@axe.com",
  #         phone_number: "12345678",
  #         mobile_number: "091712345678",
  #         fax_number: "12345678",
  #         district: "Manhattan",
  #         remarks: "Send ASAP"
  #       },
  #       pickup_address: nil,
  #       pickup_at: nil
  #     }.to_json

  #     expect(@order.to_json).to eq order_json
  #   end
  # end
end