require 'spec_helper'

RSpec.describe Xpost do
  before do
    @auth_token = auth_token
  end

  describe 'Configuration' do
    it 'has keys' do
      expect(Xpost.configuration.api_key).to eq 'api_key'
      expect(Xpost.configuration.secret_key).to eq 'secret_key'
    end

    it 'has a staging url' do
      expect(Xpost.configuration.staging_url).to eq "https://api.staging.lbcx.ph/v1"
    end

    it 'has a production url' do
      expect(Xpost.configuration.production_url).to eq "https://api.staging.lbcx.ph/v1"
    end
  end

  # TODO: need a better way to verify validity of the auth_token
  describe 'Authentication' do
    describe '.authenticate' do
      it 'returns an auth_token' do
        api_key     = Xpost.configuration.api_key
        secret_key  = Xpost.configuration.secret_key
        auth_token  = Xpost::Authentication.authenticate(api_key, secret_key)

        expect(auth_token).to_not be nil
        expect(@auth_token).to_not be nil
      end
    end
  end

  describe 'Statuses' do
    before do
      Xpost.configure do |config|
        config.api_key        = ENV['XPOST_STAGING_API_KEY']
        config.secret_key     = ENV['XPOST_STAGING_SECRET_KEY']
        config.staging_url    = "https://api.staging.lbcx.ph/v1"
        config.production_url = "https://api.staging.lbcx.ph/v1"
      end
      @auth_token = Xpost::Authentication.authenticate(Xpost.configuration.api_key, Xpost.configuration.secret_key)
    end

    it 'returns statuses' do
      statuses = Xpost::Statuses.all(@auth_token)

      expect(statuses.count).to_not eq 0
      expect(statuses.first[:name]).to eq "pending"
      expect(statuses.first[:label]).to eq "Pending"
    end

    it 'fails to retrieve statuses with an invalid auth_token' do
      statuses = Xpost::Statuses.all("random_invalid_auth_token")

      expect(statuses[:status]).to eq 401
      expect(statuses[:message]).to eq "Unauthorized"
    end
  end
end

